import { action } from '@storybook/addon-actions';
import { Meta, StoryObj } from '@storybook/react';
import React, { FC } from 'react';

import { ListPure } from '@clds/compound-components';
// eslint-disable-next-line @nx/enforce-module-boundaries
import { Edit, FaceDetect, Settings, Transform } from '@clds/icon';
// eslint-disable-next-line @nx/enforce-module-boundaries
import { Item, ItemLayout, ItemStyleProps } from '@clds/item';

type Story = StoryObj<PureComponentsControls>;

const Demo: FC<PureComponentsControls> = ({
  isStriped,
  borderRadius,
  selectManage,
  selectEditTrans,
  selectAnalyze,
  selectEdit,
}) => (
  <ListPure borderRadius={borderRadius}>
    <Item
      isStriped={isStriped}
      selectionVariant="subtle"
      borderRadius={borderRadius}
      onClick={action('manage clicked')}
      isSelected={selectManage}
    >
      <ItemLayout leftSlot={<Settings />}>Manage</ItemLayout>
    </Item>
    <Item
      isStriped={isStriped}
      selectionVariant="subtle"
      borderRadius={borderRadius}
      onClick={action('edit trans. clicked')}
      isSelected={selectEditTrans}
    >
      <ItemLayout leftSlot={<Transform />}>Edit Transformations</ItemLayout>
    </Item>
    <Item
      isStriped={isStriped}
      selectionVariant="subtle"
      borderRadius={borderRadius}
      onClick={action('analyze clicked')}
      isSelected={selectAnalyze}
    >
      <ItemLayout leftSlot={<FaceDetect />}>Analyze</ItemLayout>
    </Item>
    <Item
      isStriped={isStriped}
      selectionVariant="subtle"
      borderRadius={borderRadius}
      onClick={action('edit clicked')}
      isSelected={selectEdit}
    >
      <ItemLayout leftSlot={<Edit />}>Edit</ItemLayout>
    </Item>
  </ListPure>
);

export const PureComponents: Story = {
  render: (props) => (
    <>
      <h1>Pure list components</h1>
      <p>
        This story demonstrates how you can use very fundamental primitives of
        lists.
      </p>
      <p>
        ListPure and ListItemPure are not connected in any way and you configure
        properties of each individual component.
      </p>
      <p>
        Please look at actions panel to check click handlers. Also please look
        at controls panel to control selection of each item.
      </p>
      <Demo {...props} />
    </>
  ),
};

export interface PureComponentsControls extends ItemStyleProps {
  selectManage: boolean;
  selectEditTrans: boolean;
  selectAnalyze: boolean;
  selectEdit: boolean;
}

PureComponents.args = {
  isStriped: false,
  borderRadius: 'md',
  selectManage: false,
  selectEditTrans: false,
  selectAnalyze: true,
  selectEdit: false,
};

const meta: Meta<typeof Demo> = {
  title: 'Compound Components/01 Pure Components',
  // @ts-ignore
  component: PureComponents,
  args: {
    isStriped: false,
    borderRadius: 'md',
    selectManage: false,
    selectEditTrans: false,
    selectAnalyze: true,
    selectEdit: false,
  },
  argTypes: {},
};

export default meta;
