import { action } from '@storybook/addon-actions';
import React, {
  ChangeEvent,
  useRef,
  FC,
  useCallback,
  useState,
  SyntheticEvent,
} from 'react';

import createFakeEvent from '@clds/create-fake-event';

export default { title: 'CreateFakeEvent' };

const onChangeAction = action('random text change');

const getRandomText = (len: number): string =>
  new Array(len)
    .fill(null)
    .map(() => String.fromCharCode(Math.floor(Math.random() * 26) + 97))
    .join('');

const RandomTextInput: FC<{
  onChange: (val: string, e: SyntheticEvent) => void;
}> = ({ onChange }) => {
  const inputRef = useRef(null);
  const [value, setValue] = useState(getRandomText(6));

  const onChangeAdapted = useCallback(
    (value: string) => {
      const fakeEvent = createFakeEvent(inputRef.current);
      onChange(value, fakeEvent);
    },
    [onChange],
  );

  const onInputChange = useCallback(
    (e: ChangeEvent<HTMLInputElement>) => {
      const newVal = getRandomText(Math.max(e.currentTarget.value.length, 2));
      setValue(newVal);
      onChangeAdapted(newVal);
    },
    [onChangeAdapted],
  );

  const onButtonClick = useCallback(() => {
    const newVal = getRandomText(6);
    setValue(newVal);
    onChangeAdapted(newVal);
  }, [onChangeAdapted]);

  return (
    <>
      <input
        value={value}
        onChange={onInputChange}
        ref={inputRef}
        data-chromatic="ignore"
      />
      <br />
      <button onClick={onButtonClick}>Randomize</button>
    </>
  );
};

export const Example = () => <RandomTextInput onChange={onChangeAction} />;
